@@ -17,15 +17,22 @@ class Impact(object):
     template.
     """
 
-    def __init__(self, topology):
+    H_6R_OF_2 = 0.5612310241546865  # The half of the sixth root of 2
+
+    def __init__(self, topology, for_amber=False):
         """
         Initializes an Impact object.
 
         Parameters
         ----------
-        topology : a Topology object
+        topology : a peleffy.topology.Topology object
             The molecular topology representation to write as a
             Impact template
+        for_amber : bool
+            Whether to save an Impact file compatible with PELE's
+            Amber force field implementation or not. Default is
+            False which will create an Impact file compatible
+            with OPLS2005
 
         Examples
         --------
@@ -38,7 +45,7 @@ class Impact(object):
 
         >>> from peleffy.forcefield import OpenForceField
 
-        >>> openff = OpenForceField('openff_unconstrained-1.2.1.offxml')
+        >>> openff = OpenForceField('openff_unconstrained-2.0.0.offxml')
         >>> parameters = openff.parameterize(molecule)
 
         >>> from peleffy.topology import Topology
@@ -50,6 +57,26 @@ class Impact(object):
         >>> impact = Impact(topology)
         >>> impact.to_file('molz')
 
+        Write the Impact template of a peleffy's molecule compatible with PELE's Amber forcefield implementation
+
+        >>> from peleffy.topology import Molecule
+
+        >>> molecule = Molecule('molecule.pdb')
+
+        >>> from peleffy.forcefield import OpenForceField
+
+        >>> openff = OpenForceField('openff_unconstrained-2.0.0.offxml')
+        >>> parameters = openff.parameterize(molecule)
+
+        >>> from peleffy.topology import Topology
+
+        >>> topology = Topology(molecule, parameters)
+
+        >>> from peleffy.template import Impact
+
+        >>> impact = Impact(topology, for_amber=True)
+        >>> impact.to_file('molz')
+
         """
         import peleffy
 
@@ -59,6 +86,7 @@ class Impact(object):
                 isinstance(topology, peleffy.topology.topology.Topology)):
             raise TypeError('Invalid input molecule for Impact template')
 
+        self._for_amber = for_amber
         self._topology = deepcopy(topology)
         self._molecule = self._topology.molecule
         self._sort()
@@ -231,6 +259,10 @@ class Impact(object):
         file.write('\n')
         file.write('* File generated with peleffy-{}\n'.format(
             peleffy.__version__))
+        if self._for_amber:
+            file.write('* Compatible with PELE\'s AMBER implementation\n')
+        else:
+            file.write('* Compatible with PELE\'s OPLS implementation\n')
         file.write('*\n')
 
     def _write_resx(self, file):
@@ -303,7 +335,10 @@ class Impact(object):
             file.write('{:5d}'.format(w_atom.index))
             file.write(' ')
             # Sigma
-            file.write('{: 8.4f}'.format(w_atom.sigma))
+            if self._for_amber:
+                file.write('{: 8.4f}'.format(w_atom.sigma * self.H_6R_OF_2))
+            else:
+                file.write('{: 8.4f}'.format(w_atom.sigma))
             file.write(' ')
             # Epsilon
             file.write('{: 8.4f}'.format(w_atom.epsilon))
@@ -497,6 +532,402 @@ class Impact(object):
         """
         return self._topology
 
+    @classmethod
+    def from_file(cls, impact_file):
+        """
+        It loads an Impact template object from a file.
+
+        Parameters
+        ----------
+        impact_file : str
+            The path to the impact file
+
+        Returns
+        -------
+        molecule : a peleffy.topology.Molecule object
+            The resulting Molecule object
+        """
+        molecule_tag, n_atoms, n_bonds, n_angles, n_propers_impropers, _ = \
+            cls._retrive_template_information(impact_file)
+
+        with open(impact_file) as file:
+            impact_template_content = file.read()
+
+        resx_section = cls._get_section(impact_template_content,
+                                        molecule_tag, n_atoms)
+        nbon_section = cls._get_section(impact_template_content,
+                                        'NBON', n_atoms)
+        bond_section = cls._get_section(impact_template_content,
+                                        'BOND', n_bonds)
+        thet_section = cls._get_section(impact_template_content,
+                                        'THET', n_angles)
+        phi_section, iphi_section = cls._get_phi_iphi_sections(
+            impact_template_content, n_propers_impropers)
+
+        molecule = cls._build_molecule(resx_section, bond_section)
+
+        return molecule
+
+    @staticmethod
+    def _retrive_template_information(impact_file):
+        """
+        Given an Impact template, it retrieves the basic template
+        information.
+
+        Parameters
+        ----------
+        impact_file : str
+            The path to the impact file
+
+        Returns
+        -------
+        molecule_tag : str
+            The tag of the molecule
+        n_atoms : int
+            The number of atoms
+        n_bonds : int
+            The number of bonds
+        n_angles : int
+            The number of angles
+        n_propers_impropers : int
+            The number of propers and impropers
+        n_interactions : int
+            The number of interactions
+        """
+        with open(impact_file) as file:
+            for line in file:
+                line = line.strip()
+
+                # Ignore lines starting by '*'
+                if line.startswith('*'):
+                    continue
+
+                # Parse template information
+                if len(line) < 39:
+                    raise ValueError("Template information line in " +
+                                     "'resx' section has an invalid " +
+                                     "format")
+
+                try:
+                    molecule_tag = line[:3]
+                    n_atoms = int(line[5:11])
+                    n_bonds = int(line[11:17])
+                    n_angles = int(line[17:23])
+                    n_propers_impropers = int(line[23:31])
+                    n_interactions = int(line[31:39])
+                except TypeError:
+                    raise ValueError("Template information line in " +
+                                     "'resx' section has an invalid " +
+                                     "format")
+
+                break
+
+            else:
+                raise ValueError("Template information line in " +
+                                 "'resx' section has an invalid " +
+                                 "format")
+
+        return molecule_tag, n_atoms, n_bonds, n_angles, \
+               n_propers_impropers, n_interactions
+
+    @staticmethod
+    def _get_section(impact_template_content, section_name, n_lines):
+        """
+        Given the content of an impact template, it retrieves a
+        specific section.
+
+        Parameters
+        ----------
+        impact_template_content : str
+            The content of the impact template
+        section_name : str
+            The name of the section
+        n_lines : int
+            The number of lines to retrieve from this section
+
+        Returns
+        -------
+        section : list[str]
+            List of lines that belong to the chosen section
+        """
+        impact_template_lines = impact_template_content.split('\n')
+
+        for line_num, line in enumerate(impact_template_lines,
+                                        start=1):
+            if line.startswith(section_name):
+                break
+        else:
+            raise ValueError(f"Supplied template has an invalid format. " +
+                             f"'{section_name}' section could not be " +
+                             f"found")
+
+        section = impact_template_lines[line_num: line_num + n_lines]
+
+        return section
+
+    @staticmethod
+    def _get_phi_iphi_sections(impact_template_content, n_lines):
+        """
+        Given the content of an impact template, it retrieves the phi
+        and iphi sections.
+
+        Parameters
+        ----------
+        impact_template_content : str
+            The content of the impact template
+        n_lines : int
+            The number of lines to retrieve from phi and iphi sections
+
+        Returns
+        -------
+        phi_section : str
+            List of lines that belong to the phi section
+        iphi_section : str
+            List of lines that belong to the iphi section
+        """
+        impact_template_lines = impact_template_content.split('\n')
+
+        phi_section = list()
+        iphi_section = list()
+
+        inside_phi = False
+        inside_iphi = False
+
+        for line_num, line in enumerate(impact_template_lines,
+                                        start=1):
+            if line.startswith('PHI'):
+                inside_iphi = False
+                inside_phi = True
+                continue
+
+            if line.startswith('IPHI'):
+                inside_phi = False
+                inside_iphi = True
+                continue
+
+            if line.startswith('END'):
+                break
+
+            if inside_phi:
+                phi_section.append(line)
+
+            if inside_iphi:
+                iphi_section.append(line)
+
+            if len(phi_section) + len(iphi_section) == n_lines:
+                break
+
+        else:
+            raise ValueError(f"Supplied template has an invalid format. " +
+                             f"'PHI' and 'IPHI' sections could not be " +
+                             f"found")
+
+        if len(phi_section) + len(iphi_section) != n_lines:
+            raise ValueError(f"Supplied template has an invalid format. " +
+                             f"'PHI' and 'IPHI' sections have a wrong " +
+                             f"number of parameters")
+
+        return phi_section, iphi_section
+
+    @staticmethod
+    def _get_atomic_number_from_pdb_name(pdb_name):
+        """
+        Given a PDB atom name, it inferres the atomic element and
+        returns its atomic number.
+
+        Parameters
+        ----------
+        pdb_name : str
+            The PDB atom name
+
+        Returns
+        -------
+        atomic_number : int
+            The atomic number corresponding to the inferred atomic element
+        """
+        elements = ['H', 'He', 'Li', 'Be', 'B', 'C', 'N',
+                    'O', 'F', 'Ne', 'Na', 'Mg', 'Al', 'Si',
+                    'P', 'S', 'Cl', 'Ar', 'K', 'Ca', 'Sc',
+                    'Ti', 'V', 'Cr', 'Mn', 'Fe', 'Co', 'Ni',
+                    'Cu', 'Zn', 'Ga', 'Ge', 'As', 'Se', 'Br',
+                    'Kr', 'Rb', 'Sr', 'Y', 'Zr', 'Nb', 'Mo',
+                    'Tc', 'Ru', 'Rh', 'Pd', 'Ag', 'Cd', 'In',
+                    'Sn', 'Sb', 'Te', 'I', 'Xe']  # without periods 6 and 7, and lanthanides and actinides
+
+        non_digit_pdb_name = ''.join([c for c in pdb_name
+                                      if not c.isdigit() and
+                                      c != '_'])
+        non_digit_pdb_name = non_digit_pdb_name[0].upper() + \
+                             non_digit_pdb_name[1:].lower()
+
+        if non_digit_pdb_name in elements:
+            atomic_number = elements.index(non_digit_pdb_name) + 1
+            return atomic_number
+
+        one_char_less_pdb_name = non_digit_pdb_name
+
+        while len(one_char_less_pdb_name) > 1:
+            one_char_less_pdb_name = one_char_less_pdb_name[:-1]
+
+            if one_char_less_pdb_name in elements:
+                atomic_number = elements.index(one_char_less_pdb_name) + 1
+                return atomic_number
+
+        raise ValueError(f"Atomic number cannot be inferred "
+                         f"from {pdb_name}")
+
+    @staticmethod
+    def _from_zmatrix_to_cartesians(zmatrix):
+        """
+        Given a zmatrix it finds the corresponding cartesian coordinates.
+
+        Inspired by https://github.com/jevandezande/zmatrix
+        """
+        import numpy as np
+        from peleffy.utils import rotation_matrix
+
+        n_atoms = len(zmatrix)
+        coords = np.zeros((n_atoms, 3))
+
+        for atom_id, zmatrix_row in enumerate(zmatrix):
+            if atom_id == 0:
+                q_coords = np.array((1.0, 0.0, 0.0))
+                r_coords = np.array((0.0, 0.0, 1.0))
+                s_coords = np.array((0.0, 0.0, 0.0))
+
+            elif atom_id == 1:
+                q_coords = coords[atom_id - 1]
+                r_coords = np.array((1.0, 0.0, 0.0))
+                s_coords = np.array((0.0, 0.0, 1.0))
+
+            elif atom_id == 2:
+                q_coords = coords[atom_id - 1]
+                r_coords = coords[atom_id - 2]
+                s_coords = np.array((1.0, 0.0, 0.0))
+
+            else:
+                q_coords = coords[atom_id - 1]
+                r_coords = coords[atom_id - 2]
+                s_coords = coords[atom_id - 3]
+
+            # Take data from zmatrix row
+            distance, angle, dihedral = zmatrix_row
+
+            # Vector pointing from q to r
+            a_vector = r_coords - q_coords
+            # Vector pointing from s to r
+            b_vector = r_coords - s_coords
+
+            # Vector of length distance pointing from q to r
+            d_vector = distance * a_vector / np.sqrt(np.dot(a_vector, a_vector))
+
+            # Vector normal to plane defined by q, r, s
+            n_vector = np.cross(a_vector, b_vector)
+
+            # Rotate d vector by the angle around the normal to the
+            # plane defined by q, r, s
+            d_vector = np.dot(rotation_matrix(n_vector, angle), d_vector)
+
+            # Rotate d around a by the dihedral
+            d_vector = np.dot(rotation_matrix(a_vector, dihedral), d_vector)
+
+            # Add d to the position of q to get the new coordinates of the atom
+            p_coords = q_coords + d_vector
+
+            # Append d coordinates to cartesian coordinates list
+            coords[atom_id] = p_coords
+
+        return coords
+
+    @staticmethod
+    def _build_molecule(resx_section, bond_section):
+        """
+        Given an Impact template, it generates the corresponding
+        molecule object.
+
+        Parameters
+        ----------
+        resx_section : list[str]
+            The 'resx' section
+        bond_section : list[str]
+            The 'bond' section
+
+        Returns
+        -------
+        molecule : a peleffy.topology.Molecule object
+            The resulting Molecule object
+        """
+        # TODO transfer to RDKit toolkit
+        from rdkit.Chem import AllChem as Chem
+
+        import numpy as np
+
+        molecule = Chem.Mol()
+        editable_molecule = Chem.EditableMol(molecule)
+
+        n_atoms = len(resx_section)
+        zmatrix = np.zeros((n_atoms, 3))
+
+        for atom_id, atom_data in enumerate(resx_section):
+            try:
+                _ = int(atom_data[0:5])  # index
+                _ = int(atom_data[6:11])  # parent index
+                _ = atom_data[12]  # core
+                _ = atom_data[15:19]  # opls_type
+                pdb_name = atom_data[22:26]
+                _ = int(atom_data[27:32])  # unknown
+                zmatrix_x = float(atom_data[33:44])
+                zmatrix_y = float(atom_data[45:56])
+                zmatrix_z = float(atom_data[58:69])
+            except TypeError:
+                raise ValueError(f"Molecule could not " +
+                                 f"be built. Unexpected format " +
+                                 f"found in line: {atom_data}")
+
+            zmatrix[atom_id] = (zmatrix_x, zmatrix_y, zmatrix_z)
+
+            atomic_number = Impact._get_atomic_number_from_pdb_name(pdb_name)
+
+            atom = Chem.Atom(atomic_number)
+            atom.SetNoImplicit(True)
+            editable_molecule.AddAtom(atom)
+
+        for bond_data in bond_section:
+            try:
+                idx1 = int(bond_data[1:6])  # atom 1 index
+                idx2 = int(bond_data[7:12])  # atom 2 index
+                _ = float(bond_data[13:22])  # spring constant
+                _ = float(bond_data[23:29])  # equilibrium distance
+            except TypeError:
+                raise ValueError(f"Molecule could not " +
+                                 f"be built. Unexpected format " +
+                                 f"found in line: {bond_data}")
+
+            editable_molecule.AddBond(idx1 - 1, idx2 - 1)
+
+        molecule = editable_molecule.GetMol()
+
+        cartesians = Impact._from_zmatrix_to_cartesians(zmatrix)
+
+        # Uncomment when transformation from zmatrix to cartesians is ready
+        """
+        from rdkit.Geometry import Point3D
+
+        conformer = Chem.Conformer()
+        for atom_id in range(molecule.GetNumAtoms()):
+            x, y, z = cartesians[atom_id]
+            conformer.SetAtomPosition(atom_id, Point3D(x, y, z))
+
+        molecule.RemoveAllConformers()
+        molecule.AddConformer(conformer)
+        """
+
+        # While cartesians from zmatrix cannot be obtained, infer them with rdkit
+        # Generate 3D coordinates
+        Chem.EmbedMolecule(molecule)
+
+        return molecule
+
 
 class WritableWrapper(object):
     """
