@@ -158,6 +158,94 @@ class TestLogger(object):
             assert output == 'Critical message\n', \
                 'Unexpected logger message at standard output'
 
+    def test_get_logger_level(self):
+        """
+        It tests the level getter of peleffy's logger.
+        """
+        from peleffy.utils import Logger
+
+        logger = Logger()
+
+        # Check debug level
+        logger.set_level('DEBUG')
+        level = logger.get_level()
+        assert level == 'DEBUG', 'Unexpected Logger level'
+
+        # Check info level
+        logger.set_level('INFO')
+        level = logger.get_level()
+        assert level == 'INFO', 'Unexpected Logger level'
+
+        # Check warning level
+        logger.set_level('WARNING')
+        level = logger.get_level()
+        assert level == 'WARNING', 'Unexpected Logger level'
+
+        # Check error level
+        logger.set_level('ERROR')
+        level = logger.get_level()
+        assert level == 'ERROR', 'Unexpected Logger level'
+
+        # Check critical level
+        logger.set_level('CRITICAL')
+        level = logger.get_level()
+        assert level == 'CRITICAL', 'Unexpected Logger level'
+
+    def test_stdout_handler(self):
+        """
+        It tests the stdout handler of peleffy's logger.
+        """
+        import io
+        import logging
+        from contextlib import redirect_stdout
+        from peleffy.utils import Logger
+
+        # Force a hard reset of logging library and the logger it manages
+        from importlib import reload
+        logging.shutdown()
+        reload(logging)
+
+        logger = Logger()
+
+        with io.StringIO() as buf:
+            with redirect_stdout(buf):
+                logger.set_stdout_handler()
+
+                logger.debug('This message must not be printed')
+                logger.info('This message must be printed')
+
+            output = buf.getvalue()
+
+        assert output.strip() == 'This message must be printed', \
+            'Unexpected logger message'
+
+    def test_file_handler(self):
+        """
+        It tests the file handler of peleffy's logger.
+        """
+        import logging
+        from peleffy.utils import Logger
+        from peleffy.utils import temporary_cd
+
+        # Force a hard reset of logging library and the logger it manages
+        from importlib import reload
+        logging.shutdown()
+        reload(logging)
+
+        logger = Logger()
+
+        with tempfile.TemporaryDirectory() as tmpdir:
+            with temporary_cd(tmpdir):
+                logger.set_file_handler('log.txt')
+
+                logger.debug('This message must not be printed')
+                logger.info('This message must be printed')
+
+                with open('log.txt') as f:
+                    output = '\n'.join(f.readlines())
+
+                assert output.strip() == 'This message must be printed', \
+                    'Unexpected logger message'
 
 class TestOutputPathHandler(object):
     """
@@ -687,7 +775,14 @@ class TestPDBFile(object):
     """
     It contains all the tests to validate the PDBFile class.
     """
-    def test_get_molecule_from_chain(self):
+
+    @pytest.mark.parametrize(("complex_path", "ligand_path", "chain"),
+                             [
+                                 ('complexes/LYS_BNZ.pdb', 'ligands/BNZ.pdb', "L"),
+                                 ('complexes/5XXD_SAM.pdb', 'ligands/SAM.pdb', "A")
+                             ]
+                             )
+    def test_get_molecule_from_chain(self, complex_path, ligand_path, chain):
         """
         It tests the method that returns a molecule from a selected chain from
         an input PDB file.
@@ -724,19 +819,19 @@ class TestPDBFile(object):
         from peleffy.utils import get_data_file_path
         from peleffy.topology import Molecule
 
-        PATH_COMPLEX_PDB = get_data_file_path('complexes/LYS_BNZ.pdb')
-        PATH_LIGAND_PDB = get_data_file_path('ligands/BNZ.pdb')
+        PATH_COMPLEX_PDB = get_data_file_path(complex_path)
+        PATH_LIGAND_PDB = get_data_file_path(ligand_path)
 
         # Test method get_molecule_from_chain
         PDBreader = PDBFile(PATH_COMPLEX_PDB)
-        molecules = PDBreader.get_molecules_from_chain(selected_chain='L')
+        molecules = PDBreader.get_molecules_from_chain(selected_chain=chain)
         assert len(molecules) == 1, 'Unexpected number of molecules'
         assert compare_molecules(molecules[0], Molecule(PATH_LIGAND_PDB)) is True
 
         # Test allow_undefined_stereo flag
         PDBreader = PDBFile(PATH_COMPLEX_PDB)
         molecules = \
-            PDBreader.get_molecules_from_chain(selected_chain='L',
+            PDBreader.get_molecules_from_chain(selected_chain=chain,
                                                allow_undefined_stereo=True)
         assert len(molecules) == 1, 'Unexpected number of molecules'
         assert compare_molecules(molecules[0],
@@ -746,7 +841,7 @@ class TestPDBFile(object):
         # Test exclude_terminal_rotamers flag
         PDBreader = PDBFile(PATH_COMPLEX_PDB)
         molecules = \
-            PDBreader.get_molecules_from_chain(selected_chain='L',
+            PDBreader.get_molecules_from_chain(selected_chain=chain,
                                                exclude_terminal_rotamers=False)
         assert len(molecules) == 1, 'Unexpected number of molecules'
         assert compare_molecules(molecules[0], Molecule(
@@ -754,7 +849,7 @@ class TestPDBFile(object):
 
         # Test rotamer_resolution flag
         PDBreader = PDBFile(PATH_COMPLEX_PDB)
-        molecules = PDBreader.get_molecules_from_chain(selected_chain='L',
+        molecules = PDBreader.get_molecules_from_chain(selected_chain=chain,
                                                        rotamer_resolution=10)
         assert compare_molecules(molecules[0],
                                  Molecule(PATH_LIGAND_PDB,
@@ -762,7 +857,7 @@ class TestPDBFile(object):
 
         # Test core_constraints flag
         PDBreader = PDBFile(PATH_COMPLEX_PDB)
-        molecules = PDBreader.get_molecules_from_chain(selected_chain='L',
+        molecules = PDBreader.get_molecules_from_chain(selected_chain=chain,
                                                        core_constraints=[1,2])
         assert len(molecules) == 1, 'Unexpected number of molecules'
         assert molecules[0].core_constraints == [1,2]
@@ -849,3 +944,65 @@ class TestPDBFile(object):
         with pytest.raises(ValueError):
             PDBreader = PDBFile(PATH_COMPLEX_PDB)
             _ = PDBreader.get_molecules_from_chain(selected_chain='A')
+
+
+    def test_is_complex(self): 
+        """
+        It tests the is_complex property of a PDBFile object.
+        """
+        from peleffy.utils.input import PDBFile
+        from peleffy.utils import get_data_file_path
+
+        # The PDB fetched is a complex
+        PATH_COMPLEX_PDB = get_data_file_path('complexes/LYS_BNZ.pdb')
+        PDBreader = PDBFile(PATH_COMPLEX_PDB)
+        assert(PDBreader.is_complex)
+
+        # The PDB fetched is a ligand
+        PATH_LIGAND_PDB = get_data_file_path('ligands/benzene.pdb')
+        PDBreader = PDBFile(PATH_LIGAND_PDB)
+        assert not (PDBreader.is_complex) 
+
+    
+    def test_is_unique(self): 
+        """
+        It tests the static method is_unique. 
+        """               
+        from peleffy.utils.input import PDBFile
+        from peleffy.utils import get_data_file_path
+
+        PATH_COMPLEX_PDB = get_data_file_path('complexes/complex_test.pdb')
+        PDBreader = PDBFile(PATH_COMPLEX_PDB)
+
+        # Chain with a single molecule
+        molecules = PDBreader.get_molecules_from_chain(
+                selected_chain='L',
+                allow_undefined_stereo = True)
+        assert(PDBreader.is_unique(molecules))
+
+        # Chain with multiple molecules
+        molecules = PDBreader.get_molecules_from_chain(
+                selected_chain='C',
+                allow_undefined_stereo = True)
+        assert not(PDBreader.is_unique(molecules))
+
+class TestGeneralUtils(object):
+    """
+    It contains all the tests to validate general util methods.
+    """
+    def test_path_exists(self):
+        """
+        It tests the method to check if a path exists.
+        """
+
+        from peleffy.utils import check_if_path_exists
+        from peleffy.utils import temporary_cd
+
+        # Initialize temporary directory to check the method
+        with tempfile.TemporaryDirectory() as tmpdir:
+            with temporary_cd(tmpdir):
+                check_if_path_exists(tmpdir)
+
+        # It should no longer work once the directory is removed
+        with pytest.raises(ValueError):
+            check_if_path_exists(tmpdir)
